@@ -98,12 +98,14 @@ module Spring
       end
 
       test "crash on boot" do
-        app.run app.spring_test_command, env: {
-          "CRASH_ON_BOOT" => "1",
-          # If the command is small enough, it might fit in the socket buffer and writing the command won't block.
-          # So we send a big environment variable to better reproduce the problem.
-          "FOO" => "bar" * 4_000,
-      }
+        assert_nothing_raised do
+          app.run app.spring_test_command, env: {
+            "CRASH_ON_BOOT" => "1",
+            # If the command is small enough, it might fit in the socket buffer and writing the command won't block.
+            # So we send a big environment variable to better reproduce the problem.
+            "FOO" => "bar" * 4_000,
+          }
+        end
       end
 
       test "help message when called without arguments" do
@@ -144,7 +146,12 @@ module Spring
         end
         File.write(config_path, config)
 
-        assert_failure "bin/rails runner 1", stderr: "Please, set config.cache_classes to false"
+        expected_error = Regexp.union(
+          "Please, set config.enable_reloading to true",
+          "Please, set config.cache_classes to false"
+        )
+
+        assert_failure "bin/rails runner 1", stderr: expected_error
       end
 
       test "test changes are picked up" do
@@ -288,7 +295,7 @@ module Spring
       test "binstub when spring binary is missing" do
         begin
           File.rename(app.path("bin/spring"), app.path("bin/spring.bak"))
-          assert_failure "bin/rake -T", stderr: "`load': cannot load such file"
+          assert_failure "bin/rake -T", stderr: "load': cannot load such file"
         ensure
           File.rename(app.path("bin/spring.bak"), app.path("bin/spring"))
         end
@@ -661,8 +668,6 @@ module Spring
       end
 
       test "custom bundle path" do
-        skip if Gem::Version.new(RUBY_VERSION) < Gem::Version.new("3.1.0") && ENV["RAILS_VERSION"] == "7.0"
-
         bundle_path = app.path(".bundle/#{Bundler.ruby_scope}")
         bundle_path.dirname.mkpath
 
